@@ -2,7 +2,7 @@ from asyncio import sleep
 from re import search
 from typing import Union
 
-from discord import MISSING, PermissionOverwrite, Member, Role, Message
+from discord import MISSING, PermissionOverwrite, Member, Role, Message, CategoryChannel, PartialMessage
 from discord.utils import _MissingSentinel
 
 from .utils.utils_message import utils_get_message
@@ -21,7 +21,9 @@ __all__ = [
     'dshell_create_voice_channel',
     'dshell_edit_text_channel',
     'dshell_edit_voice_channel',
-    'dshell_edit_thread'
+    'dshell_edit_thread',
+    'dshell_create_category',
+    'dshell_edit_category'
 ]
 
 
@@ -206,6 +208,7 @@ async def dshell_delete_channels(ctx: Message, name=None, regex=None, reason=Non
 async def dshell_edit_text_channel(ctx: Message,
                                    channel=None,
                                    name=None,
+                                   category=MISSING,
                                    position=MISSING,
                                    slowmode=MISSING,
                                    topic=MISSING,
@@ -215,10 +218,15 @@ async def dshell_edit_text_channel(ctx: Message,
     """
     Edits a text channel on the server
     """
+    if name is not None and not isinstance(name, str):
+        raise Exception(f"Name must be a string, not {type(name)} !")
 
     if not isinstance(position, (_MissingSentinel, int)):
         raise Exception(f"Position must be an integer, not {type(position)} !")
 
+    if not isinstance(category, (_MissingSentinel, int)):
+        raise Exception(f"Category must be an integer, not {type(category)} !")
+
     if not isinstance(slowmode, (_MissingSentinel, int)):
         raise Exception(f"Slowmode must be an integer, not {type(slowmode)} !")
 
@@ -229,12 +237,14 @@ async def dshell_edit_text_channel(ctx: Message,
         raise Exception(f"NSFW must be a boolean, not {type(nsfw)} !")
 
     channel_to_edit = ctx.channel if channel is None else ctx.channel.guild.get_channel(channel)
+    new_categoy = ctx.channel.category if isinstance(category, _MissingSentinel) else ctx.channel.guild.get_channel(category)
 
     if channel_to_edit is None:
         raise Exception(f"Channel {channel} not found !")
 
     await channel_to_edit.edit(name=name if name is not None else channel_to_edit.name,
                                position=position if position is not MISSING else channel_to_edit.position,
+                               category=new_categoy,
                                slowmode_delay=slowmode if slowmode is not MISSING else channel_to_edit.slowmode_delay,
                                topic=topic if topic is not MISSING else channel_to_edit.topic,
                                nsfw=nsfw if nsfw is not MISSING else channel_to_edit.nsfw,
@@ -247,6 +257,7 @@ async def dshell_edit_text_channel(ctx: Message,
 async def dshell_edit_voice_channel(ctx: Message,
                                     channel=None,
                                     name=None,
+                                    category=MISSING,
                                     position=MISSING,
                                     bitrate=MISSING,
                                     permissions: dict[Union[Member, Role], PermissionOverwrite] = MISSING,
@@ -257,16 +268,21 @@ async def dshell_edit_voice_channel(ctx: Message,
     if not isinstance(position, (_MissingSentinel, int)):
         raise Exception(f"Position must be an integer, not {type(position)} !")
 
+    if not isinstance(category, (_MissingSentinel, int)):
+        raise Exception(f"Category must be an integer, not {type(category)} !")
+
     if not isinstance(bitrate, (_MissingSentinel, int)):
         raise Exception(f"Bitrate must be an integer, not {type(bitrate)} !")
 
     channel_to_edit = ctx.channel if channel is None else ctx.channel.guild.get_channel(channel)
+    new_categoy = ctx.channel.category if isinstance(category, _MissingSentinel) else ctx.channel.guild.get_channel(category)
 
     if channel_to_edit is None:
         raise Exception(f"Channel {channel} not found !")
 
     await channel_to_edit.edit(name=name if name is not None else channel_to_edit.name,
                                position=position if position is not MISSING else channel_to_edit.position,
+                               category=new_categoy,
                                bitrate=bitrate if bitrate is not MISSING else channel_to_edit.bitrate,
                                overwrites=permissions if permissions is not MISSING else channel_to_edit.overwrites,
                                reason=reason)
@@ -304,7 +320,11 @@ async def dshell_create_thread_message(ctx: Message,
     if not isinstance(slowmode, _MissingSentinel) and slowmode < 0:
         raise Exception("Slowmode delay must be a positive integer !")
 
-    m = await message.fetch()
+    if isinstance(message, PartialMessage):
+        m = await message.fetch()
+    else:
+        m = message
+
     thread = await m.create_thread(name=name,
                     auto_archive_duration=archive,
                     slowmode_delay=slowmode)
@@ -356,7 +376,11 @@ async def dshell_get_thread(ctx: Message, message: Union[int, str] = None):
     if message is None:
         message = ctx.id
 
-    message = await utils_get_message(ctx, message).fetch()
+    target_message = utils_get_message(ctx, message)
+    if isinstance(target_message, PartialMessage):
+        message = await target_message.fetch()
+    else:
+        message = target_message
 
     if not hasattr(message, 'thread'):
         return None
@@ -377,7 +401,11 @@ async def dshell_delete_thread(ctx: Message, thread: Union[int, str] = None, rea
     if thread is None:
         thread = ctx.id
 
-    thread = await utils_get_message(ctx, thread).fetch()
+    target_message = utils_get_message(ctx, thread)
+    if isinstance(target_message, PartialMessage):
+        thread = await target_message.fetch()
+    else:
+        thread = target_message
 
     if not hasattr(thread, 'thread'):
         raise Exception("The specified message does not have a thread !")
@@ -389,3 +417,60 @@ async def dshell_delete_thread(ctx: Message, thread: Union[int, str] = None, rea
 
     return thread.thread.id
 
+async def dshell_create_category(ctx: Message,
+                                   name,
+                                   position=MISSING,
+                                   permissions: dict[Union[Member, Role], PermissionOverwrite] = MISSING,
+                                   reason=None):
+    """
+    Creates a category on the server
+    """
+
+    if not isinstance(position, (_MissingSentinel, int)):
+        raise Exception(f"Position must be an integer, not {type(position)} !")
+
+    created_category = await ctx.guild.create_category(str(name),
+                                                      position=position,
+                                                      overwrites=permissions,
+                                                      reason=reason)
+
+    return created_category.id
+
+async def dshell_edit_category(ctx: Message,
+                                category,
+                                name=None,
+                                position=MISSING,
+                                permissions: dict[Union[Member, Role], PermissionOverwrite] = MISSING,
+                                reason=None):
+    """
+    Edits a category on the server
+    """
+    if not isinstance(position, (_MissingSentinel, int)):
+        raise Exception(f"Position must be an integer, not {type(position)} !")
+
+    category_to_edit = ctx.channel.guild.get_channel(category)
+
+    if category_to_edit is None or not isinstance(category_to_edit, CategoryChannel):
+        raise Exception(f"Category {category} not found or is not a category !")
+
+    await category_to_edit.edit(name=name if name is not None else category_to_edit.name,
+                                position=position if position is not MISSING else category_to_edit.position,
+                                overwrites=permissions if permissions is not MISSING else category_to_edit.overwrites,
+                                reason=reason)
+
+    return category_to_edit.id
+
+async def dshell_get_channel_category_id(ctx: Message, channel=None):
+    """
+    Returns the category ID of a channel.
+    """
+
+    channel_to_check = ctx.channel if channel is None else ctx.channel.guild.get_channel(channel)
+
+    if channel_to_check is None:
+        raise Exception(f"Channel {channel} not found !")
+
+    if channel_to_check.category is None:
+        return None
+
+    return channel_to_check.category.id if channel_to_check.category is not None else 0
\ No newline at end of file
