@@ -1,11 +1,11 @@
-from re import search
-
-from discord import Embed, Message
+from discord import Embed, Message, PartialMessage
 from discord.ext import commands
+from typing import Optional
 
 from pycordViews import EasyModifiedViews
 
 from .utils.utils_message import utils_get_message, utils_autorised_mentions
+from .._DshellInterpreteur.cached_messages import dshell_cached_messages
 from .._utils import NoneType
 
 __all__ = [
@@ -14,12 +14,15 @@ __all__ = [
     'dshell_delete_message',
     'dshell_purge_message',
     'dshell_edit_message',
-    'dshell_get_hystory_messages',
-    'dshell_research_regex_in_content',
+    'dshell_get_history_messages',
     'dshell_add_reactions',
     'dshell_remove_reactions',
     'dshell_clear_message_reactions',
-    'dshell_clear_one_reactions'
+    'dshell_clear_one_reactions',
+    'dshell_get_content_message',
+    'dshell_get_author_id_message',
+    'dshell_get_message_link',
+    'dshell_get_message_category_id',
 ]
 
 
@@ -167,7 +170,9 @@ async def dshell_edit_message(ctx: Message, message, new_content=None, embeds=No
     return edit_message.id
 
 
-async def dshell_get_hystory_messages(ctx: Message, channel=None, limit=None) -> "ListNode":
+async def dshell_get_history_messages(ctx: Message,
+                                      channel=None,
+                                      limit=None) -> "ListNode":
     """
     Searches for messages matching a regex in a channel
     """
@@ -182,29 +187,19 @@ async def dshell_get_hystory_messages(ctx: Message, channel=None, limit=None) ->
 
     from .._DshellParser.ast_nodes import ListNode
 
+    cached_messages = dshell_cached_messages.get()
     messages = ListNode([])
     async for message in search_channel.history(limit=limit):
-        messages.add(message)
+        message_id = message.id
+        messages.add(message_id)
+        cached_messages[message_id] = message
 
     if not messages:
         raise commands.CommandError(f"No messages in {search_channel.mention}.")
-
+    dshell_cached_messages.set(cached_messages)
     return messages
 
 
-async def dshell_research_regex_in_content(ctx: Message, regex, content=None):
-    """
-    Searches for a regex in a specific message content
-    """
-
-    if not isinstance(regex, str):
-        raise Exception(f"Regex must be a string, not {type(regex)}!")
-
-    if not search(regex, str(content) if content is not None else ctx.content):
-        return False
-
-    return True
-
 
 async def dshell_add_reactions(ctx: Message, reactions, message=None):
     """
@@ -257,3 +252,80 @@ async def dshell_clear_one_reactions(ctx: Message, message, emoji):
     target_message = ctx if message is None else utils_get_message(ctx, message)
 
     await target_message.clear_reaction(emoji)
+
+async def dshell_get_content_message(ctx: Message, message=None):
+    """
+    Get the content of a message
+    """
+
+    target_message = ctx if message is None else utils_get_message(ctx, message)
+
+    if isinstance(target_message, PartialMessage):
+        try:
+            fetch_target_message = await target_message.fetch()
+        except:
+            raise Exception(f'Message not found !')
+    else:
+        fetch_target_message = target_message
+
+    return fetch_target_message.content
+
+
+async def dshell_get_author_id_message(ctx: Message, message: Optional[int] = None):
+    """
+    Return author ID of the message given (or ctx if message=None)
+    :param ctx:
+    :param message: message ID
+    :return:
+    """
+    if message is not None and not isinstance(message, int):
+        raise Exception(f'Message parameter must be an integer or None, not {type(message)} !')
+
+    target_message = ctx
+    if message is not None:
+        target_message = utils_get_message(ctx, message)
+
+        if isinstance(target_message, PartialMessage):
+            try:
+                target_message = await target_message.fetch()
+            except:
+                raise Exception(f"[message_author] Author ID message to get is not found !")
+
+    return target_message.author.id
+
+async def dshell_get_message_link(ctx: Message, message: int):
+    """
+    Return the link of a message given its ID
+    :param ctx:
+    :param message: message ID
+    :return:
+    """
+    if not isinstance(message, int):
+        raise Exception(f'Message parameter must be an integer, not {type(message)} !')
+
+    target_message = utils_get_message(ctx, message)
+
+    return target_message.jump_url
+
+async def dshell_get_message_category_id(ctx: Message, message: int = None):
+    """
+    Return the category ID of a message given its ID
+    :param ctx:
+    :param message: message ID
+    :return:
+    """
+    if message is not None and not isinstance(message, int):
+        raise Exception(f'Message parameter must be an integer, not {type(message)} !')
+
+    target_message = ctx
+    if message is not None:
+        target_message = utils_get_message(ctx, message)
+
+        if isinstance(target_message, PartialMessage):
+            try:
+                target_message = await target_message.fetch()
+            except:
+                raise Exception(f"[category_message] Message ID to get is not found !")
+
+    return target_message.channel.category.id if target_message.channel.category is not None else 0
+
