@@ -99,7 +99,7 @@ def parse(token_lines: list[list[Token]], start_node: ASTNode) -> tuple[list[AST
                 if tokens_by_line[1].type != DTT.IDENT:
                     raise TypeError(f'[LOOP] the variable given must be a ident, '
                                     f'not {tokens_by_line[1].type} in line {tokens_by_line[1].position}')
-                if tokens_by_line[2].type not in (DTT.IDENT, DTT.STR, DTT.INT, DTT.FLOAT, DTT.LIST):
+                if tokens_by_line[2].type not in (DTT.IDENT, DTT.STR, DTT.INT, DTT.FLOAT, DTT.LIST, DTT.EVAL_GROUP):
                     raise TypeError(f'[LOOP] the iterator must be a ident, string, integer, float or list, '
                                     f'not {tokens_by_line[2].type} in line {tokens_by_line[2].position}')
 
@@ -262,6 +262,8 @@ def parse(token_lines: list[list[Token]], start_node: ASTNode) -> tuple[list[AST
         elif first_token_line.type == DTT.STR:
             last_block.body.append(CommandNode(name='sm', body=ArgsCommandNode([first_token_line])))
 
+        elif first_token_line.type == DTT.EVAL_GROUP:
+            parse([first_token_line.value], last_block)
 
         else:
             last_block.body += tokens_by_line
@@ -316,7 +318,7 @@ def parser_inline(tokens: list[Token]) -> tuple[list[list[Token]], bool]:
     return result, True
 
 
-def to_postfix(expression):
+def to_postfix(expression, interpreter=None):
     """
     Transforme l'expression en notation postfixée (RPN)
     :param expression: l'expression donné par le tokenizer
@@ -326,7 +328,7 @@ def to_postfix(expression):
     operators: list[Token] = []
 
     for token in expression:
-        if token.type in (DTT.IDENT, DTT.CALL_ARGS, DTT.INT, DTT.FLOAT, DTT.LIST, DTT.STR, DTT.BOOL):  # Si c'est un ident
+        if token.type in (DTT.IDENT, DTT.INT, DTT.FLOAT, DTT.LIST, DTT.STR, DTT.BOOL, DTT.EVAL_GROUP):  # Si c'est un ident
             output.append(token)
         elif token.value in dshell_operators:
             while (operators and operators[-1].value in dshell_operators and
