@@ -19,6 +19,7 @@ from ..DISCORD_COMMANDS.dshell_interaction import *
 from ..DISCORD_COMMANDS.utils.utils_global import *
 from ..DISCORD_COMMANDS.utils.utils_list import *
 from ..DISCORD_COMMANDS.utils.utils_member import *
+from ..DISCORD_COMMANDS.utils.utils_string import *
 
 dshell_keyword: set[str] = {
     'if', 'else', 'elif', 'loop', '#end', 'var', '#loop', '#if', 'sleep', 'param', '#param'
@@ -27,8 +28,20 @@ dshell_keyword: set[str] = {
 dshell_discord_keyword: set[str] = {
     'embed', '#embed', 'field', 'perm', 'permission', '#perm', '#permission', 'ui', '#ui', 'button', 'select'
 }
+
+async def dshell_debug(ctx, x):
+    """
+    Print all x parameter
+    :param ctx:
+    :param x:
+    :return:
+    """
+    print(x)
+    return x
+
 dshell_commands: dict[str, Callable] = {
 
+    "debug": dshell_debug,
     ## global utils
     'random': utils_random,
 
@@ -43,6 +56,17 @@ dshell_commands: dict[str, Callable] = {
     'reverse': utils_list_reverse,
     'get': utils_list_get_value,
 
+    ## String utils
+    'split': utils_split_string,
+    'upper': utils_upper_string,
+    'lower': utils_lower_string,
+    'title': utils_title_string,
+    'strip': utils_strip_string,
+    'replace': utils_replace_string,
+    'regex_findall': utils_regex_findall,
+    'regex_sub': utils_regex_sub,
+    'regex': utils_regex_search,
+
     ## Discord utils
     'name': utils_get_name, # get the name from id (channel, role, member)
     'id': utils_get_id, # get the id from name (channel, role, member)
@@ -61,6 +85,11 @@ dshell_commands: dict[str, Callable] = {
     "dm": dshell_delete_message,
     "pm": dshell_purge_message,
     "em": dshell_edit_message,  # edit message
+    "mh": dshell_get_history_messages,  # get message history
+    "gcm": dshell_get_content_message,  # get content of a message
+    "gma": dshell_get_author_id_message,  # get author id of a message
+    "gml": dshell_get_message_link,  # get message link
+    "gmc": dshell_get_message_category_id,  # get message category id
 
     "sri": dshell_respond_interaction,  # respond to an interaction
     "sdi": dshell_defer_interaction,  # defer an interaction
@@ -68,6 +97,7 @@ dshell_commands: dict[str, Callable] = {
 
     "cc": dshell_create_text_channel,  # create channel
     "cvc": dshell_create_voice_channel,  # create voice channel
+    "cca": dshell_create_category,  # create category
     "dc": dshell_delete_channel,  # delete channel
     "dcs": dshell_delete_channels,  # delete several channels by name or regex
 
@@ -90,11 +120,9 @@ dshell_commands: dict[str, Callable] = {
     "gmr": dshell_give_member_roles, # give roles
     "rmr": dshell_remove_member_roles, # remove roles
 
-    "ghm": dshell_get_hystory_messages,  # research regex in message
-    "src": dshell_research_regex_in_content,  # research regex in content
-
     "ec": dshell_edit_text_channel,  # edit text channel
     "evc": dshell_edit_voice_channel,  # edit voice channel
+    "eca": dshell_edit_category,  # edit category
 
     "cr": dshell_create_role, # create role
     "dr": dshell_delete_roles, # delete role
@@ -148,57 +176,3 @@ dshell_logical_operators: dict[str, tuple[Callable, int]] = {
 dshell_operators: dict[str, tuple[Callable, int]] = dshell_logical_operators.copy()
 dshell_operators.update(dshell_logical_word_operators)
 dshell_operators.update(dshell_mathematical_operators)
-
-'''
-C_create_var = "var"
-    C_obligate_var = "ovar" # makes variables mandatory
-
-    # guild
-    C_create_channel = "cc"
-    C_create_voice_channel = "cvc"
-    C_create_forum_channel = "cfc"
-    C_create_category = "cca"
-    C_create_role = "cr"
-
-    C_delete_channel = "dc"
-    C_delete_category = "dca"
-    C_delete_role = "dr"
-
-    C_edit_channel = "ec"
-    C_edit_voice_channel = "evc"
-    C_edit_forum_channel = "efc"
-    C_edit_category = "eca"
-    C_edit_role = "er"
-    C_edit_guild = "eg"
-
-    # forum
-    C_edit_ForumTag = "eft"
-    C_create_thread = "ct"
-    C_delete_tread = "dt"
-
-    # member
-    C_edit_nickname = "en"
-    C_ban_member = "bm"
-    C_unban_member = "um"
-    C_kick_member = "km"
-    C_timeout_member = "tm"
-    C_move_member = "mm"
-    C_add_roles = "ar"
-    C_remove_roles = "rr"
-
-    # message
-    C_send_message = "sm"
-    C_respond_message = "rm"
-    C_edit_message = "em"
-    C_send_user_message = "sum"
-    C_delete_message = "dm"
-    C_purge_message = "pm"
-    C_create_embed = "e"
-    C_regex = "regex"
-    C_add_emoji = "ae"
-    C_remove_emoji = "re"
-    C_clear_emoji = "ce"
-    C_remove_reaction = "rre"
-
-    # button
-    C_create_button = "b"'''
